#ifndef _EFL_UI_WIN_SOCKET_LEGACY_EO_H_
#define _EFL_UI_WIN_SOCKET_LEGACY_EO_H_

#ifndef _EFL_UI_WIN_SOCKET_LEGACY_EO_CLASS_TYPE
#define _EFL_UI_WIN_SOCKET_LEGACY_EO_CLASS_TYPE

typedef Eo Efl_Ui_Win_Socket_Legacy;

#endif

#ifndef _EFL_UI_WIN_SOCKET_LEGACY_EO_TYPES
#define _EFL_UI_WIN_SOCKET_LEGACY_EO_TYPES


#endif
#ifdef EFL_BETA_API_SUPPORT
/** Elementary window socket class
 *
 * @ingroup Efl_Ui_Win_Socket_Legacy
 */
#define EFL_UI_WIN_SOCKET_LEGACY_CLASS efl_ui_win_socket_legacy_class_get()

EWAPI const Efl_Class *efl_ui_win_socket_legacy_class_get(void) EINA_CONST;
#endif /* EFL_BETA_API_SUPPORT */

#endif
